# BigBuyPy

Continuous Integration Status: [![<ORG_NAME>](https://circleci.com/gh/devandrepascoa/BigBuyPy.svg?style=svg)](https://app.circleci.com/pipelines/github/devandrepascoa/BigBuyPy)

Big Buy connector for python